@@ -1,6 +1,13 @@
-tINV <- function(tnsr,tform) {
+tINV <- function(tnsr,tform)
+{
+  # Performs inverse of 3-mode tensor using any
+  # discrete transform.
+
+  # Input: tnsr, a 3D tensor
+  # Output: The inverse of tnsr, a 3D tensor
+
   if (tnsr@num_modes != 3)
-    stop("T-SVD only implemented for 3d so far")
+    stop("tINV only implemented for 3d so far")
   modes <- tnsr@modes
   n1 <- modes[1]
   n2 <- modes[2]
